Package: xCell2
Type: Package
Title: A Tool for Generic Cell Type Enrichment Analysis
Version: 1.2.0
Authors@R: 
    c(person(given = "Almog", 
             family = "Angel", 
             role = c("aut", "cre"),
             email = "almog.angel@campus.technion.ac.il",
             comment = c(ORCID = "0009-0001-3297-6935")),
             person(given = "Dvir", 
             family = "Aran", 
             role = "aut",
             email = "dviraran@technion.ac.il",
             comment = c(ORCID = "0000-0001-6334-5039")))
Description: xCell2 provides methods for cell type enrichment analysis using cell type signatures.
    It includes three main functions - 
    1. xCell2Train for training custom references objects from bulk or single-cell RNA-seq datasets.
    2. xCell2Analysis for conducting the cell type enrichment analysis using the custom reference.
    3. xCell2GetLineage for identifying dependencies between different cell types using ontology.
License: GPL (>= 3)
Encoding: UTF-8
LazyData: false
Depends: R (>= 4.0.0)
biocViews: GeneExpression, Transcriptomics, Microarray, RNASeq,
        SingleCell, DifferentialExpression, ImmunoOncology,
        GeneSetEnrichment
Imports: SummarizedExperiment, SingleCellExperiment, Rfast, singscore,
        AnnotationHub, ontologyIndex, tibble, dplyr, BiocParallel,
        Matrix, minpack.lm, pracma, methods, readr, magrittr, progress,
        quadprog
Suggests: testthat, knitr, rmarkdown, ggplot2, randomForest, tidyr,
        EnhancedVolcano, BiocStyle
RoxygenNote: 7.3.2
VignetteBuilder: knitr
URL: https://github.com/AlmogAngel/xCell2
BugReports: https://github.com/AlmogAngel/xCell2/issues
git_url: https://git.bioconductor.org/packages/xCell2
git_branch: RELEASE_3_22
git_last_commit: d42142a
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 07:14:24 UTC; biocbuild
Author: Almog Angel [aut, cre] (ORCID: <https://orcid.org/0009-0001-3297-6935>),
  Dvir Aran [aut] (ORCID: <https://orcid.org/0000-0001-6334-5039>)
Maintainer: Almog Angel <almog.angel@campus.technion.ac.il>
